'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var ToggleIcon = _interopDefault(require('@material-ui/icons/PlayCircleFilled'));
var DeleteIcon = _interopDefault(require('@material-ui/icons/Delete'));
var CancelIcon = _interopDefault(require('@material-ui/icons/Cancel'));
var EditIcon = _interopDefault(require('@material-ui/icons/Edit'));
var _ = _interopDefault(require('lodash'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var DataLabel = function DataLabel(_ref) {
  var type = _ref.type;
  return React__default.createElement("span", {
    style: {
      padding: '0px 6px',
      color: 'gray',
      border: '1px solid gray',
      borderRadius: 5,
      fontSize: 11,
      margin: '0 3px'
    }
  }, type);
};

var JsonNumber = function JsonNumber(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var _useState = React.useState(),
      currentValue = _useState[0],
      setCurrentValue = _useState[1];

  var _useState2 = React.useState(false),
      showInput = _useState2[0],
      setShowInput = _useState2[1];

  React.useEffect(function () {
    setCurrentValue(value);
  }, [value]);

  var showEditInput = function showEditInput() {
    setShowInput(true);
  };

  var editValue = function editValue() {
    onEdit(currentValue, dataKey);
    setShowInput(false);
  };

  var deleteValue = function deleteValue() {
    onDelete(dataKey);
    setShowInput(false);
  };

  var cancelEdit = function cancelEdit() {
    setShowInput(false);
  };

  return React__default.createElement("div", {
    className: 'p5'
  }, React__default.createElement("span", null, React__default.createElement("span", null, "\""), React__default.createElement("span", null, dataKey), React__default.createElement("span", null, "\""), " : ", React__default.createElement(DataLabel, {
    type: dataType
  }), showInput ? React__default.createElement("span", null, React__default.createElement("input", {
    className: 'p5 NumProperty',
    type: 'number',
    defaultValue: currentValue,
    onChange: function onChange(e) {
      return setCurrentValue(e.target.value);
    }
  }), React__default.createElement(EditIcon, {
    className: 'editIcon',
    onClick: editValue
  }), React__default.createElement(DeleteIcon, {
    className: 'deleteIcon',
    onClick: deleteValue
  }), React__default.createElement(CancelIcon, {
    className: 'cancelIcon',
    onClick: cancelEdit
  })) : React__default.createElement("span", {
    style: {
      color: 'blue'
    },
    onClick: showEditInput
  }, currentValue)));
};

var JsonString = function JsonString(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var _useState = React.useState(),
      currentValue = _useState[0],
      setCurrentValue = _useState[1];

  var _useState2 = React.useState(false),
      showInput = _useState2[0],
      setShowInput = _useState2[1];

  React.useEffect(function () {
    setCurrentValue(value);
  }, [value]);

  var showEditInput = function showEditInput() {
    setShowInput(true);
  };

  var editValue = function editValue() {
    onEdit(currentValue, dataKey);
    setShowInput(false);
  };

  var deleteValue = function deleteValue() {
    onDelete(dataKey);
    setShowInput(false);
  };

  var cancelEdit = function cancelEdit() {
    setShowInput(false);
  };

  return React__default.createElement("div", {
    style: {
      padding: 5
    }
  }, React__default.createElement("span", null, React__default.createElement("span", null, "\""), React__default.createElement("span", null, dataKey), React__default.createElement("span", null, "\""), " : ", React__default.createElement(DataLabel, {
    type: dataType
  }), React__default.createElement("span", null, "\""), React__default.createElement("span", {
    style: {
      color: '#FF6767'
    }
  }, showInput ? React__default.createElement("span", null, React__default.createElement("textarea", {
    className: 'textInput',
    style: {
      padding: 5
    },
    defaultValue: currentValue,
    onChange: function onChange(e) {
      return setCurrentValue(e.target.value);
    }
  }), React__default.createElement("span", null, React__default.createElement(EditIcon, {
    style: {},
    className: 'editIcon',
    onClick: editValue
  })), React__default.createElement(DeleteIcon, {
    className: 'deleteIcon',
    onClick: deleteValue
  }), React__default.createElement(CancelIcon, {
    className: 'cancelIcon',
    onClick: cancelEdit
  })) : React__default.createElement("span", {
    className: 'JsonValue',
    onClick: showEditInput
  }, currentValue)), React__default.createElement("span", null, "\"")));
};

var JsonBool = function JsonBool(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType;
  return React__default.createElement("div", {
    style: {
      padding: 5
    }
  }, React__default.createElement("span", null, React__default.createElement("span", null, "\""), React__default.createElement("span", null, dataKey), React__default.createElement("span", null, "\""), " : ", React__default.createElement(DataLabel, {
    type: dataType
  }), React__default.createElement("span", {
    style: {
      color: 'green'
    }
  }, value)));
};

function getTypes(value) {
  if (Array.isArray(value)) return 'array';
  return typeof value;
}

var JsonObject = function JsonObject(_ref) {
  var value = _ref.value,
      dataKey = _ref.dataKey,
      dataType = _ref.dataType,
      onDelete = _ref.onDelete;

  var _useState = React.useState(true),
      col = _useState[0],
      setCol = _useState[1];

  var _useState2 = React.useState([]),
      keys = _useState2[0],
      setKeys = _useState2[1];

  var _useState3 = React.useState({}),
      currentValue = _useState3[0],
      setCurrentValue = _useState3[1];

  React.useEffect(function () {
    setCurrentValue(value);
    setKeys(Object.keys(value ? value : ""));
  }, [value]);

  var EditOneProperty = function EditOneProperty(newValue, key) {
    var newObj = _extends({}, currentValue);

    newObj[key] = newValue;
    setCurrentValue(newObj);
  };

  var DeleteOneProperty = function DeleteOneProperty(key) {
    var newObj;
    newObj = _.omit(currentValue, key);
    newObj ? setCurrentValue(newObj) : "";
    newObj ? setKeys(Object.keys(newObj)) : "";
  };

  var renderObject = function renderObject() {
    return keys.map(function (k, i) {
      return React__default.createElement(Index, {
        key: i,
        dataType: currentValue ? getTypes(currentValue[k]) : "",
        dataValue: currentValue ? currentValue[k] : "",
        dataKey: k,
        onEdit: EditOneProperty,
        onDelete: DeleteOneProperty
      });
    });
  };

  var renderObjContent = function renderObjContent() {
    if (col) return React__default.createElement("div", {
      className: 'p5 ml6'
    }, React__default.createElement("div", {
      onClick: toggleObj
    }, React__default.createElement(ToggleIcon, {
      onClick: toggleObj,
      className: 'collapseIcon'
    }), React__default.createElement("span", null, "\"", dataKey, "\""), React__default.createElement("span", null, ":"), React__default.createElement("span", {
      className: 'boldStyle pl5'
    }, '{'), React__default.createElement("span", null, React__default.createElement(DeleteIcon, {
      className: 'deleteIcon',
      onClick: function onClick() {
        onDelete(dataKey);
      }
    }), React__default.createElement(CancelIcon, {
      className: 'cancelIcon'
    })), React__default.createElement(DataLabel, {
      type: dataType ? dataType : ""
    })), React__default.createElement("div", {
      className: 'pl12'
    }, renderObject(), React__default.createElement("div", null, React__default.createElement("span", {
      className: 'boldStyle'
    }, '}'))));
    return React__default.createElement("div", {
      className: 'p5 ml6'
    }, React__default.createElement("div", null, React__default.createElement(ToggleIcon, {
      onClick: toggleObj,
      className: 'collapseIcon'
    }), "\"", dataKey, "\":", React__default.createElement("span", {
      className: 'boldStyle'
    }, '{', React__default.createElement(DataLabel, {
      type: dataType ? dataType : ""
    })), React__default.createElement("span", {
      className: 'colorGray'
    }, keys.length, " items"), React__default.createElement("span", {
      className: 'boldStyle'
    }, '}')));
  };

  var toggleObj = function toggleObj() {
    // setCurrentValue(currentValue);
    setCol(!col);
  };

  return renderObjContent();
};

var JsonFunction = function JsonFunction(_ref) {
  var dataKey = _ref.dataKey,
      dataType = _ref.dataType;
  return React__default.createElement("div", {
    className: 'p5'
  }, React__default.createElement("span", null, React__default.createElement("span", null, "\""), React__default.createElement("span", null, dataKey), React__default.createElement("span", null, "\""), " : ", React__default.createElement(DataLabel, {
    type: dataType
  }), React__default.createElement("span", {
    style: {
      color: 'blue'
    }
  }, "Function()")));
};

var Index = function Index(_ref) {
  var dataType = _ref.dataType,
      dataValue = _ref.dataValue,
      dataKey = _ref.dataKey,
      onEdit = _ref.onEdit,
      onDelete = _ref.onDelete;

  var renderValue = function renderValue() {
    switch (dataType) {
      case 'number':
        return React__default.createElement(JsonNumber, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onEdit: onEdit,
          onDelete: onDelete
        });

      case 'string':
        return React__default.createElement(JsonString, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onEdit: onEdit,
          onDelete: onDelete
        });

      case 'object':
        return React__default.createElement(JsonObject, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType,
          onDelete: onDelete,
          onEdit: onEdit
        });

      case 'boolean':
        return React__default.createElement(JsonBool, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType
        });
      // case 'array':
      //   return (
      //     <JsonArray value={dataValue} dataKey={dataKey} dataType={dataType} />
      //   );

      case 'function':
        return React__default.createElement(JsonFunction, {
          value: dataValue,
          dataKey: dataKey,
          dataType: dataType
        });

      default:
        return null;
    }
  };

  return renderValue();
};

var DataView = function DataView(_ref) {
  var data = _ref.data,
      onDelete = _ref.onDelete,
      onEdit = _ref.onEdit;

  var _useState = React.useState(false),
      col = _useState[0],
      setCol = _useState[1];

  var _useState2 = React.useState([]),
      keys = _useState2[0],
      setKeys = _useState2[1];

  var _useState3 = React.useState({}),
      currentData = _useState3[0],
      setCurrentData = _useState3[1];

  React.useEffect(function () {
    var newkeys = Object.getOwnPropertyNames(data);
    setKeys(newkeys);
    setCurrentData(data);
  }, [data]);

  var toggleJsonView = function toggleJsonView() {
    setCol(!col);
  };

  var renderData = function renderData() {
    if (col) return React__default.createElement("div", {
      className: 'p5'
    }, React__default.createElement("span", {
      className: 'colorGray'
    }, React__default.createElement("span", null, '{'), currentData ? Object.keys(currentData).length : "", " items", React__default.createElement("span", null, '}')));
    return keys.map(function (k) {
      return React__default.createElement("div", {
        key: k
      }, React__default.createElement(Index, {
        key: k,
        dataType: currentData ? getTypes(currentData[k]) : "",
        dataValue: currentData ? currentData[k] : "",
        dataKey: k,
        onEdit: onEdit,
        onDelete: onDelete
      }));
    });
  };

  return React__default.createElement("div", {
    className: 'JsonTree'
  }, React__default.createElement("div", null, React__default.createElement(ToggleIcon, {
    onClick: toggleJsonView,
    className: 'mainCollapseIcon'
  }), "\"root\" :", React__default.createElement("span", {
    className: 'boldStyle pl5'
  }, '{'), renderData(), React__default.createElement("div", {
    className: 'boldStyle '
  }, '}')));
};

var JsJsonView = function JsJsonView(_ref) {
  var resource = _ref.resource;

  var _useState = React.useState({}),
      currentResource = _useState[0],
      setCurrentResource = _useState[1];

  React.useEffect(function () {
    setCurrentResource(resource);
  }, [resource]); // edit a property from the object

  var EditObj = function EditObj(newValue, key) {
    var newObj = _extends({}, currentResource);

    newObj[key] = newValue;
    setCurrentResource(newObj);
  }; // delete a property from the object


  var DeleteObj = function DeleteObj(key) {
    var currentValue = _extends({}, currentResource);

    delete currentValue[key]; // _.omit(currentResource, key)

    setCurrentResource(currentValue);
  };

  return React__default.createElement("div", {
    className: 'appContainer',
    "data-testid": 'Json-tree'
  }, React__default.createElement(DataView, {
    data: currentResource,
    onDelete: DeleteObj,
    onEdit: EditObj
  }));
};

exports.default = JsJsonView;
//# sourceMappingURL=js-json-tree.cjs.development.js.map
